import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";
import React from 'react';
import PropTypes from 'prop-types';
import { Controlled as ControlledCodeMirror } from 'react-codemirror2';
import { FlatButton, Toolbar, ToolbarGroup } from 'material-ui';
import { editorTypes } from './editorTypes';
import 'codemirror/lib/codemirror.css';
import 'codemirror/mode/xml/xml';
import 'codemirror/mode/sql/sql';
import 'codemirror/mode/javascript/javascript';
export var CodeMirrorCore = function CodeMirrorCore(_ref) {
  var _ref$input = _ref.input,
      value = _ref$input.value,
      onChange = _ref$input.onChange,
      _ref$meta = _ref.meta,
      valid = _ref$meta.valid,
      error = _ref$meta.error,
      type = _ref.type,
      label = _ref.label,
      _ref$defaultValue = _ref.defaultValue,
      defaultValue = _ref$defaultValue === void 0 ? '' : _ref$defaultValue,
      required = _ref.required;
  var _editorTypes$type = editorTypes[type],
      mode = _editorTypes$type.mode,
      format = _editorTypes$type.format,
      parse = _editorTypes$type.parse,
      stringify = _editorTypes$type.stringify;
  return React.createElement("div", null, React.createElement("span", {
    style: {
      color: '#c4c4c4'
    }
  }, label, required ? ' * ' : ' '), valid ? null : React.createElement("span", {
    style: {
      color: '#ff3d3a'
    }
  }, " (", error, ")"), Boolean(format) && React.createElement(Toolbar, {
    noGutter: true
  }, React.createElement(ToolbarGroup, null, React.createElement(FlatButton, {
    label: "Format",
    onClick: function onClick() {
      return onChange(format(value));
    }
  }))), React.createElement(ControlledCodeMirror, {
    label: label,
    value: stringify(value || defaultValue),
    options: {
      mode: mode,
      lineNumbers: true,
      lineWrapping: true
    },
    onBeforeChange: function onBeforeChange(editor, data, valueFromEditor) {
      onChange(parse(valueFromEditor));
    }
  }));
};
var valueType = PropTypes.oneOfType([PropTypes.string, PropTypes.array, PropTypes.object]);
CodeMirrorCore.propTypes = {
  input: PropTypes.shape({
    value: valueType,
    onChange: PropTypes.func
  }),
  meta: PropTypes.shape({
    valid: PropTypes.bool,
    error: PropTypes.string
  }),
  record: PropTypes.object,
  type: PropTypes.oneOf(Object.keys(editorTypes)).isRequired,
  label: PropTypes.node.isRequired,
  defaultValue: valueType,
  required: PropTypes.bool
};