import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es6.date.to-string";
import sqlFormatter from 'sql-formatter';
import formatHtml from 'pretty';

var parse = function parse(value) {
  return value;
};

var stringify = function stringify(value) {
  var _value;

  return ((_value = value) !== null && _value !== void 0 ? _value : '').toString();
};

export var editorTypes = {
  sql: {
    mode: 'text/x-sql',
    format: function format(value) {
      return sqlFormatter.format(value);
    },
    parse: parse,
    stringify: stringify
  },
  json: {
    mode: 'application/json',
    format: function format(value) {
      try {
        if (typeof value === 'string') {
          return JSON.stringify(JSON.parse(value), null, 2);
        }

        return JSON.stringify(value, null, 2);
      } catch (_unused) {
        return value;
      }
    },
    parse: function parse(value) {
      try {
        if (typeof value === 'string') return JSON.parse(value);
      } catch (_unused2) {
        return value;
      }
    },
    stringify: function stringify(value) {
      if (value) {
        if (typeof value === 'string') return value;

        try {
          return JSON.stringify(value, null, 2);
        } catch (_unused3) {
          return value;
        }
      }

      return '';
    }
  },
  html: {
    mode: 'text/html',
    format: function format(value) {
      return formatHtml(value);
    },
    parse: parse,
    stringify: stringify
  }
};